aboutsummaryrefslogtreecommitdiff
path: root/core/api.ts
diff options
context:
space:
mode:
Diffstat (limited to 'core/api.ts')
-rw-r--r--core/api.ts9
1 files changed, 5 insertions, 4 deletions
diff --git a/core/api.ts b/core/api.ts
index 017e131..51f976a 100644
--- a/core/api.ts
+++ b/core/api.ts
@@ -1,12 +1,13 @@
import { ParseResult } from "../language/types.ts";
/**
- * @summary API interface
+ * @summary Core interface
*
* This interface gets implemented by all API clients, so clients can be
* swapped easily.
*/
-export default abstract class API {
+export default abstract class Core {
/** @summary resolved when ready */
abstract ready: Promise<void>;
@@ -1,12 +1,13 @@
*
- * This interface gets implemented by all API clients, so clients can be
- * swapped easily.
+ * This interface gets implemented by all Core clients, so clients can be
+ * swapped easily. You should probably not directly use any Core, but use the
+ * abstracted API from ../api/
*/